@@ -4,8 +4,9 @@ import urllib
 import uuid
 
 from django.conf import settings
-from google_analytics import CAMPAIGN_TRACKING_PARAMS
+from django.utils.translation import get_language_from_request
 
+from google_analytics import CAMPAIGN_TRACKING_PARAMS
 
 VERSION = '1'
 COOKIE_NAME = '__utmmobile'
@@ -47,21 +48,18 @@ def set_cookie(params, response):
     return response
 
 
-def build_ga_params(request, path=None, event=None, referer=None):
+def build_ga_params(
+        request, account, path=None, event=None, referer=None, title=None):
     meta = request.META
-
-    # get the account id
-    try:
-        account = settings.GOOGLE_ANALYTICS['google_analytics_id']
-    except:
-        raise Exception("No Google Analytics ID configured")
-
     # determine the domian
     domain = meta.get('HTTP_HOST', '')
 
     # determine the referrer
     referer = referer or request.GET.get('r', '')
 
+    custom_uip = None
+    if hasattr(settings, 'CUSTOM_UIP_HEADER') and settings.CUSTOM_UIP_HEADER:
+        custom_uip = meta.get(settings.CUSTOM_UIP_HEADER)
     # get the path from the referer header
     path = path or request.GET.get('p', '/')
 
@@ -83,12 +81,16 @@ def build_ga_params(request, path=None, event=None, referer=None):
         'dh': domain,
         'sr': '',
         'dr': referer,
-        'dp': path,
+        'dp': urllib.quote(path.encode('utf-8')),
         'tid': account,
         'cid': visitor_id,
-        'uip': client_ip,
+        'uip': custom_uip or client_ip,
     }
 
+    # add page title if supplied
+    if title:
+        u_title = title.decode('utf-8') if isinstance(title, str) else title
+        params.update({'dt': urllib.quote(unicode(u_title).encode('utf-8'))})
     # add event parameters if supplied
     if event:
         params.update({
@@ -114,11 +116,12 @@ def build_ga_params(request, path=None, event=None, referer=None):
 
     # construct the gif hit url
     ga_url = "http://www.google-analytics.com/collect"
-    utm_url = ga_url + "?" + urllib.urlencode(params)
+    utm_url = ga_url + "?&" + urllib.urlencode(params)
+    locale = get_language_from_request(request)
 
     return {'utm_url': utm_url,
             'user_agent': user_agent,
-            'language': meta.get('HTTP_ACCEPT_LANGUAGE', ''),
+            'language': locale or settings.LANGUAGE_CODE,
             'visitor_id': visitor_id,
             'COOKIE_USER_PERSISTENCE': COOKIE_USER_PERSISTENCE,
             'COOKIE_NAME': COOKIE_NAME,
